@@ -1,16 +1,30 @@
+import logging
 from datetime import datetime, timezone
 
 import jwt
 from django.db import models, transaction
 from django.db.models import Q
 
+from ..settings import auth_settings
+from ..utils import decrypt_with_cipher
+
 
 __all__ = ["RefreshTokenRotationLog"]
 
 
+logger = logging.getLogger(__name__)
+
+
 class RefreshTokenRotationLogManager(models.Manager):
     def remove_by_token_title(self, token: str) -> None:
         """Remove logs with a title matching the given token's "sub" claim, plus all expired logs."""
+        if auth_settings.CIPHER_KEY is not None:
+            try:
+                token = decrypt_with_cipher(token)
+            except RuntimeError as error:
+                logger.exception("Cannot decrypt token.", exc_info=error)
+                return
+
         payload = jwt.decode(jwt=token, options={"verify_signature": False})
         self.remove_by_title(title=str(payload["sub"]))
 
